chardet package
===============

Module contents
---------------

.. automodule:: chardet
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

chardet.enums module
--------------------

.. automodule:: chardet.enums
    :members:
    :undoc-members:
    :show-inheritance:

chardet.resultdict module
-------------------------

.. automodule:: chardet.resultdict
    :members:
    :undoc-members:
    :show-inheritance:

chardet.universaldetector module
--------------------------------

.. automodule:: chardet.universaldetector
    :members:
    :undoc-members:
    :show-inheritance:

chardet.charsetprober module
----------------------------

.. automodule:: chardet.charsetprober
    :members:
    :undoc-members:
    :show-inheritance:

chardet.charsetgroupprober module
---------------------------------

.. automodule:: chardet.charsetgroupprober
    :members:
    :undoc-members:
    :show-inheritance:

chardet.codingstatemachine module
---------------------------------

.. automodule:: chardet.codingstatemachine
    :members:
    :undoc-members:
    :show-inheritance:

chardet.codingstatemachinedict module
-------------------------------------

.. automodule:: chardet.codingstatemachinedict
    :members:
    :undoc-members:
    :show-inheritance:

Multi-byte encoding probers
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

chardet.mbcharsetprober module
------------------------------

.. automodule:: chardet.mbcharsetprober
    :members:
    :undoc-members:
    :show-inheritance:

chardet.mbcsgroupprober module
------------------------------

.. automodule:: chardet.mbcsgroupprober
    :members:
    :undoc-members:
    :show-inheritance:

chardet.mbcssm module
---------------------

.. automodule:: chardet.mbcssm
    :members:
    :undoc-members:
    :show-inheritance:

chardet.utf8prober module
-------------------------

.. automodule:: chardet.utf8prober
    :members:
    :undoc-members:
    :show-inheritance:

chardet.utf1632prober module
----------------------------

.. automodule:: chardet.utf1632prober
    :members:
    :undoc-members:
    :show-inheritance:

chardet.big5prober module
-------------------------

.. automodule:: chardet.big5prober
    :members:
    :undoc-members:
    :show-inheritance:

chardet.gb18030prober module
----------------------------

.. automodule:: chardet.gb18030prober
    :members:
    :undoc-members:
    :show-inheritance:

chardet.eucjpprober module
--------------------------

.. automodule:: chardet.eucjpprober
    :members:
    :undoc-members:
    :show-inheritance:

chardet.euckrprober module
--------------------------

.. automodule:: chardet.euckrprober
    :members:
    :undoc-members:
    :show-inheritance:

chardet.cp949prober module
--------------------------

.. automodule:: chardet.cp949prober
    :members:
    :undoc-members:
    :show-inheritance:

chardet.sjisprober module
-------------------------

.. automodule:: chardet.sjisprober
    :members:
    :undoc-members:
    :show-inheritance:

chardet.johabprober module
--------------------------

.. automodule:: chardet.johabprober
    :members:
    :undoc-members:
    :show-inheritance:

chardet.escprober module
------------------------

.. automodule:: chardet.escprober
    :members:
    :undoc-members:
    :show-inheritance:

chardet.escsm module
--------------------

.. automodule:: chardet.escsm
    :members:
    :undoc-members:
    :show-inheritance:

Single-byte encoding probers
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

chardet.sbcharsetprober module
------------------------------

.. automodule:: chardet.sbcharsetprober
    :members:
    :undoc-members:
    :show-inheritance:

chardet.sbcsgroupprober module
------------------------------

.. automodule:: chardet.sbcsgroupprober
    :members:
    :undoc-members:
    :show-inheritance:

chardet.hebrewprober module
---------------------------

.. automodule:: chardet.hebrewprober
    :members:
    :undoc-members:
    :show-inheritance:

Analysis modules
^^^^^^^^^^^^^^^^

chardet.chardistribution module
-------------------------------

.. automodule:: chardet.chardistribution
    :members:
    :undoc-members:
    :show-inheritance:

chardet.jpcntx module
---------------------

.. automodule:: chardet.jpcntx
    :members:
    :undoc-members:
    :show-inheritance:

Frequency tables
^^^^^^^^^^^^^^^^

chardet.big5freq module
-----------------------

.. automodule:: chardet.big5freq
    :members:
    :undoc-members:
    :show-inheritance:

chardet.euckrfreq module
------------------------

.. automodule:: chardet.euckrfreq
    :members:
    :undoc-members:
    :show-inheritance:

chardet.gb2312freq module
-------------------------

.. automodule:: chardet.gb2312freq
    :members:
    :undoc-members:
    :show-inheritance:

chardet.jisfreq module
----------------------

.. automodule:: chardet.jisfreq
    :members:
    :undoc-members:
    :show-inheritance:

chardet.johabfreq module
------------------------

.. automodule:: chardet.johabfreq
    :members:
    :undoc-members:
    :show-inheritance:

Language models
^^^^^^^^^^^^^^^

These modules contain bigram frequency models for single-byte encoding
detection. They are generated by ``create_language_model.py`` and should
not be edited manually.

.. automodule:: chardet.langarabicmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langbelarusianmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langbretonmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langbulgarianmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langcroatianmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langczechmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langdanishmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langdutchmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langenglishmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langesperantomodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langestonianmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langfarsimodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langfinnishmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langfrenchmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langgermanmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langgreekmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langhebrewmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langhungarianmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langicelandicmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langindonesianmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langirishmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langitalianmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langkazakhmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langlatvianmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langlithuanianmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langmacedonianmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langmalaymodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langmaltesemodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langnorwegianmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langpolishmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langportuguesemodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langromanianmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langrussianmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langscottishgaelicmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langserbianmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langslovakmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langslovenemodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langspanishmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langswedishmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langtajikmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langthaimodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langturkishmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langukrainianmodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langvietnamesemodel
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: chardet.langwelshmodel
    :members:
    :undoc-members:
    :show-inheritance:

CLI module
^^^^^^^^^^

chardet.cli.chardetect module
-----------------------------

.. automodule:: chardet.cli.chardetect
    :members:
    :undoc-members:
    :show-inheritance:

Metadata subpackage
^^^^^^^^^^^^^^^^^^^

chardet.metadata.charsets module
--------------------------------

.. automodule:: chardet.metadata.charsets
    :members:
    :undoc-members:
    :show-inheritance:

chardet.metadata.languages module
---------------------------------

.. automodule:: chardet.metadata.languages
    :members:
    :undoc-members:
    :show-inheritance:
